summaryrefslogtreecommitdiff
path: root/src/dkp-device-list.c
diff options
context:
space:
mode:
authorRichard Hughes <richard@hughsie.com>2009-06-15 19:56:04 +0100
committerRichard Hughes <richard@hughsie.com>2009-06-15 19:56:04 +0100
commit8ae8f3a5b5cb58d742d995d57f832138e5ddce6d (patch)
tree5fc28780e4b6cec583699a2b0d51ed99ba25a173 /src/dkp-device-list.c
parent454e81349d0444e4e96d64b23df225225f98629f (diff)
downloadupower-8ae8f3a5b5cb58d742d995d57f832138e5ddce6d.tar.gz
Initial search/replace port to GUdev. No testing done.
Diffstat (limited to 'src/dkp-device-list.c')
-rw-r--r--src/dkp-device-list.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/dkp-device-list.c b/src/dkp-device-list.c
index 8d41b71..0e08001 100644
--- a/src/dkp-device-list.c
+++ b/src/dkp-device-list.c
@@ -46,11 +46,11 @@ G_DEFINE_TYPE (DkpDeviceList, dkp_device_list, G_TYPE_OBJECT)
/**
* dkp_device_list_lookup:
*
* Convert a %DevkitDevice into a %DkpDevice -- we use the native path
* to look these up as it's the only thing they share.
**/
DkpDevice *
-dkp_device_list_lookup (DkpDeviceList *list, DevkitDevice *d)
+dkp_device_list_lookup (DkpDeviceList *list, GUdevDevice *d)
{
DkpDevice *device;
const gchar *native_path;
@@ -58,7 +58,7 @@ dkp_device_list_lookup (DkpDeviceList *list, DevkitDevice *d)
g_return_val_if_fail (DKP_IS_DEVICE_LIST (list), NULL);
/* does device exist in db? */
- native_path = devkit_device_get_native_path (d);
+ native_path = g_udev_device_get_sysfs_path (d);
device = g_hash_table_lookup (list->priv->map_native_path_to_device, native_path);
return device;
}
@@ -66,11 +66,11 @@ dkp_device_list_lookup (DkpDeviceList *list, DevkitDevice *d)
/**
* dkp_device_list_insert:
*
* Insert a %DevkitDevice device and it's mapping to a %DkpDevice device
* into a list of devices.
**/
gboolean
-dkp_device_list_insert (DkpDeviceList *list, DevkitDevice *d, DkpDevice *device)
+dkp_device_list_insert (DkpDeviceList *list, GUdevDevice *d, DkpDevice *device)
{
const gchar *native_path;
@@ -78,7 +78,7 @@ dkp_device_list_insert (DkpDeviceList *list, DevkitDevice *d, DkpDevice *device)
g_return_val_if_fail (d != NULL, FALSE);
g_return_val_if_fail (device != NULL, FALSE);
- native_path = devkit_device_get_native_path (d);
+ native_path = g_udev_device_get_sysfs_path (d);
g_hash_table_insert (list->priv->map_native_path_to_device,
g_strdup (native_path), device);
g_ptr_array_add (list->priv->array, device);
@@ -118,7 +118,7 @@ dkp_device_list_remove (DkpDeviceList *list, DkpDevice *device)
/**
* dkp_device_list_get_array:
*
* This is quick to iterate when we don't have DevkitDevice's to resolve
**/
const GPtrArray *
dkp_device_list_get_array (DkpDeviceList *list)
@@ -46,11 +46,11 @@ G_DEFINE_TYPE (DkpDeviceList, dkp_device_list, G_TYPE_OBJECT)
* dkp_device_list_lookup:
*
- * Convert a %DevkitDevice into a %DkpDevice -- we use the native path
+ * Convert a %GUdevDevice into a %DkpDevice -- we use the native path
* to look these up as it's the only thing they share.
**/
@@ -66,11 +66,11 @@ dkp_device_list_lookup (DkpDeviceList *list, DevkitDevice *d)
* dkp_device_list_insert:
*
- * Insert a %DevkitDevice device and it's mapping to a %DkpDevice device
+ * Insert a %GUdevDevice device and it's mapping to a %DkpDevice device
* into a list of devices.
**/
@@ -118,7 +118,7 @@ dkp_device_list_remove (DkpDeviceList *list, DkpDevice *device)
* dkp_device_list_get_array:
*
- * This is quick to iterate when we don't have DevkitDevice's to resolve
+ * This is quick to iterate when we don't have GUdevDevice's to resolve
**/
const GPtrArray *